==> realt-1.0.2-rc.10.tgz: package/es/reducers/createInstance.js <==
import _Object$keys from 'babel-runtime/core-js/object/keys';
import isFunction from 'lodash/isFunction';
import toConstant from '../utils/toConstant';
import makeActionHandler from './makeActionHandler';

function createInstanceByClass(ReducerClass, typePrefix) {
  var reducers = [];

  /* eslint-disable no-param-reassign */

  /**
   * Attaches reducer's handler function to specific action type
   * @param {Function} reducerHandler
   * @param {Object} actionCreator
   */
  ReducerClass.prototype.bindHandler = function bindHandler(reducerHandler, actionCreator) {
    reducers.push(makeActionHandler(reducerHandler, typePrefix, actionCreator.toString(), this.initialState));
  };

  /**
   * Binds actionCreator for specific reducer handler function
   * @param {Object} actionCreator
   * @param {Function} reducerHandler
   */
  ReducerClass.prototype.bindAction = function bindAction(actionCreator, reducerHandler) {
    this.bindHandler(reducerHandler, actionCreator);
  };

  /* eslint-enable no-param-reassign */

  var reducer = new ReducerClass();

  return { reducers: reducers, initialState: reducer.initialState };
}

function createInstanceByObject(reducerObject, typePrefix) {
  var reducers = [];
  var prefixes = ['handle', 'reducerFor'];
  var initialState = reducerObject.initialState;

  var actionType = null;
  var reducerHandler = null;

  _Object$keys(reducerObject).forEach(function (reducer) {
    actionType = reducer;
    prefixes.forEach(function (prefix) {
      if (reducer.includes(prefix)) actionType = reducer.replace(prefix, '');
    });

    actionType = toConstant(actionType);
    reducerHandler = reducerObject[reducer];

    reducers.push(makeActionHandler(reducerHandler, typePrefix, actionType, initialState));
  });

  return { reducers: reducers, initialState: initialState };
}

export default function createInstance(Reducer, typePrefix) {
  if (isFunction(Reducer)) return createInstanceByClass(Reducer, typePrefix);

  return createInstanceByObject(Reducer, typePrefix);
}

==> realt-1.0.3-rc.1.tgz: package/es/reducers/createInstance.js <==
import { isFunction, toConstant } from '../utils';
import makeActionHandler from './makeActionHandler';

function createInstanceByClass(ReducerClass) {
  var reducers = [];

  /* eslint-disable no-param-reassign */

  /**
   * Attaches reducer's handler function to specific action type
   * @param {Function} reducerHandler
   * @param {Object} actionCreator
   */
  ReducerClass.prototype.bindHandler = function bindHandler(reducerHandler, actionCreator) {
    reducers.push(makeActionHandler(reducerHandler, null, actionCreator.toString(), this.initialState));
  };

  /**
   * Binds actionCreator for specific reducer handler function
   * @param {Object} actionCreator
   * @param {Function} reducerHandler
   */
  ReducerClass.prototype.bindAction = function bindAction(actionCreator, reducerHandler) {
    this.bindHandler(reducerHandler, actionCreator);
  };

  /* eslint-enable no-param-reassign */

  var reducer = new ReducerClass();

  return { reducers: reducers, initialState: reducer.initialState };
}

function createInstanceByObject(reducerObject, typePrefix) {
  var reducers = [];
  var prefixes = ['handle', 'reducerFor'];
  var initialState = reducerObject.initialState;

  var actionType = null;
  var reducerHandler = null;

  Object.keys(reducerObject).forEach(function (reducer) {
    actionType = reducer;
    prefixes.forEach(function (prefix) {
      if (reducer.includes(prefix)) actionType = reducer.replace(prefix, '');
    });

    actionType = toConstant(actionType);
    reducerHandler = reducerObject[reducer];

    reducers.push(makeActionHandler(reducerHandler, typePrefix, actionType, initialState));
  });

  return { reducers: reducers, initialState: initialState };
}

export default function createInstance(Reducer, typePrefix) {
  if (isFunction(Reducer)) return createInstanceByClass(Reducer);

  return createInstanceByObject(Reducer, typePrefix);
}
